@@ -4,14 +4,19 @@ import os
 import re
 import shutil
 from collections import defaultdict
+from datetime import datetime
 from typing import Any, Dict, List, Optional, TextIO, Tuple, Type, Union
 
 import click
 import htmlmin
 import jinja2
 import markdown2
+from jinja2 import FileSystemLoader
+from pytz import reference
 
-TEMPLATE_FILE_NAME = "templates/schema_doc.template.html"
+
+TEMPLATE_FOLDER = "templates"
+TEMPLATE_FILE_NAME = "base.html"
 CSS_FILE_NAME = "schema_doc.css"
 JS_FILE_NAME = "schema_doc.min.js"
 
@@ -315,8 +320,8 @@ def get_description(description: Optional[str]) -> str:
 
 
 def get_description_remove_default(description: Optional[str]) -> str:
-    """Filter. From the description attribute of a property, return the description without any default values in it. Will also convert None to an
-    empty string.
+    """Filter. From the description attribute of a property, return the description without any default values in it.
+    Will also convert None to an empty string.
     """
     if not description:
         return ""
@@ -429,6 +434,10 @@ def generate_id_for_pattern_property(parent_property_name: str, current_index: i
     return id_string
 
 
+def get_local_time() -> str:
+    return datetime.now(tz=reference.LocalTimezone()).strftime("%Y-%m-%d at %H:%M:%S %z")
+
+
 def generate_from_schema(
     schema: Dict[str, Any],
     schema_path: str,
@@ -443,8 +452,12 @@ def generate_from_schema(
     global paths_to_id
     paths_to_id = defaultdict(defaultdict)
 
+    template_folder = os.path.join(os.path.dirname(__file__), TEMPLATE_FOLDER)
+    base_template_path = os.path.join(template_folder, TEMPLATE_FILE_NAME)
+
     md = markdown2.Markdown(extras=["fenced-code-blocks"])
-    env = jinja2.Environment()
+    loader = FileSystemLoader(template_folder)
+    env = jinja2.Environment(loader=loader)
     env.filters["markdown"] = lambda text: jinja2.Markup(md.convert(text))
     env.filters["python_to_json"] = python_to_json
     env.filters["get_default"] = get_default_look_in_description if default_from_description else get_default
@@ -460,9 +473,9 @@ def generate_from_schema(
     env.tests["combining"] = is_combining
     env.tests["description_short"] = is_text_short
     env.tests["deprecated"] = is_deprecated_look_in_description if deprecated_from_description else is_deprecated
+    env.globals["get_local_time"] = get_local_time
 
-    template_path = os.path.join(os.path.dirname(__file__), TEMPLATE_FILE_NAME)
-    with open(template_path, "r") as template_fp:
+    with open(base_template_path, "r") as template_fp:
         template = env.from_string(template_fp.read())
 
     if isinstance(schema_path, list):
